==> haskell-bower-json-0.8.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bower-json/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 0.8.0
id: bower-json-0.8.0-937a6e95a39040baca2791b1ddd5123f
key: bower_EjYRELEbsR0BH8Grx1DguD
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/bower-json-0.8.0
hs-libraries: HSbower-json-0.8.0-EjYRELEbsR0BH8Grx1DguD
depends:
    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
    aeson-better-errors-0.9.0.1-78a0fda48af376adc445962771de1b93
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-0.8.0-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-bower-json/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 0.8.0
id: bower-json-0.8.0-e5efe5ff8a892e9a670a71c216790060
key: bower_GB106WqnVmiJ69RhKx3v2q
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
author: Harry Garrood
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/bower-json-0.8.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/bower-json-0.8.0
hs-libraries: HSbower-json-0.8.0-GB106WqnVmiJ69RhKx3v2q
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    aeson-better-errors-0.9.0.1-59403b30f4f27006e990088f17fb37ed
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
